@@ -11,13 +11,10 @@ use routines;
 use Data::Object::Class;
 use Data::Object::ClassHas;
 
-with 'Data::Object::Role::Pluggable';
 with 'Data::Object::Role::Proxyable';
-with 'Data::Object::Role::Throwable';
+with 'Faker::Maker';
 
-with 'Faker::Process';
-
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # METHODS
 
@@ -423,6 +420,8 @@ L<Data::Object::Role::Proxyable>
 
 L<Data::Object::Role::Throwable>
 
+L<Faker::Maker>
+
 =cut
 
 =head1 LIBRARIES
