@@ -13,13 +13,13 @@ use Data::Object::ClassHas;
 
 extends 'Data::Object::Plugin';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 # ATTRIBUTES
 
 has 'faker' => (
   is => 'ro',
-  isa => 'InstanceOf["Faker"]',
+  isa => 'ConsumerOf["Faker::Maker"]',
   req => 1,
 );
 
@@ -91,9 +91,9 @@ This package has the following attributes:
 
 =head2 faker
 
-  faker(InstanceOf["Faker"])
+  faker(ConsumerOf["Faker::Maker"])
 
-This attribute is read-only, accepts C<(InstanceOf["Faker"])> values, and is required.
+This attribute is read-only, accepts C<(ConsumerOf["Faker::Maker"])> values, and is required.
 
 =cut
 
